function cellIds = computeHoppingSequences(WISA_allowedfreqs)
    global fhAlgorithm
    global clicked
    global selected
    global Period
    
    [seqLengths, startIndexes] = calcConnSeqs(WISA_allowedfreqs);
    
    noOfAvFreqs = sum(seqLengths);
    
    primeNr = [2 3 2 5 7 2 3 11 13 2 17 19 23 5 3 29 31 2 37 41 43 47 7 53 59 61 2 67 71 73 79];
    powers = [1 1 2 1 1 3 2 1 1 4 1 1 1 2 3 1 1 5 1 1 1 1 2 1 1 1 6 1 1 1 1];
    allNumbers = primeNr.^powers;
    
    relNumbers = allNumbers(5:11);

    sbCalc = zeros(1, length(relNumbers));
    NoOfSbInSeq = zeros(length(seqLengths), length(relNumbers));
    
% ########################################################################
% Calculate nr of subbands given a subband width.
% ########################################################################
    for i = 1:length(seqLengths)
        NoOfSbInSeq(i,:) = floor(seqLengths(i)./relNumbers);
        sbCalc = sbCalc + NoOfSbInSeq(i,:);
    end
    possSB = sbCalc;
    
% ########################################################################
% Calculate number of subbands given a the width of a subband
% ########################################################################
    for i = 1:length(sbCalc)
       sbMatrix = zeros(sbCalc(i),relNumbers(i));
       counter = 1;
       for j = 1:length(seqLengths)
           if NoOfSbInSeq(j,i) ~= 0
               for k = 1:NoOfSbInSeq(j,i)
                   if startIndexes(j)>1
                       shift = seqLengths(j)-NoOfSbInSeq(j,i)*relNumbers(i);
                   else
                       shift = 0;
                   end
                   sbMatrix(counter,:) = WISA_allowedfreqs((startIndexes(j)+shift+(k-1)*relNumbers(i)):(startIndexes(j)+shift+k*relNumbers(i)-1));
                   counter = counter+1;
               end
           end
       end
       
       counter=0;
              
       sbDist = zeros(sbCalc(i),sbCalc(i));
       for j = 1:sbCalc(i)-1
           for k = j+1:sbCalc(i)
               sbDist(j,k) = min(sbMatrix(k,:))-max(sbMatrix(j,:));
               sbDist(k,j) = sbDist(j,k);
           end
       end
       
       sbAllowed=sbDist>=22;
       
       pairs = zeros(1,sbCalc(i));
       subbands = 1:sbCalc(i);
       level = 1;
       maxConst = 0;
       [pairs, maxConst] = pairsComp_v2(pairs, maxConst, level, subbands, sbAllowed, pairs, pairs);
       possSB(i) = maxConst;
    end
    
% ########################################################################
% Remap to nearest(lower) prime or prime extension
% ########################################################################
    for i = 1:length(possSB)
        if possSB(i) > 1
            possSB(i) = allNumbers(find(allNumbers<=possSB(i),1,'last'));
        end
    end
    
% ########################################################################
% User interface to choose wanted constellation
% ########################################################################
    usedFreqsMatrix = relNumbers.*possSB;
    save('matfiles\constellation','usedFreqsMatrix', 'relNumbers', 'possSB')
    clicked = 0;
    interactConst
    pause(3)
    while ~clicked
        pause(1)
    end    
    
    noOfSubbands = possSB(selected);
    widthOfSubbands = relNumbers(selected);
    
    subbandHS = galoisCalc(noOfSubbands);
    indexHS = galoisCalc(widthOfSubbands);

% ########################################################################
% Redoing previous calculations for selected configuration of subbands
% ########################################################################    
    i = selected;
    sbMatrix = zeros(sbCalc(i),relNumbers(i));
    counter = 1;
    for j = 1:length(seqLengths)
        if NoOfSbInSeq(j,i) ~= 0
            for k = 1:NoOfSbInSeq(j,i)
                if j>1
                       shift = seqLengths(j)-NoOfSbInSeq(j,i)*relNumbers(i);
                   else
                       shift = 0;
                   end
                   sbMatrix(counter,:) = WISA_allowedfreqs((startIndexes(j)+shift+(k-1)*relNumbers(i)):(startIndexes(j)+shift+k*relNumbers(i)-1));
                   counter = counter+1;
            end
        end
    end
    counter=0;
    
    sbDist = zeros(sbCalc(i),sbCalc(i));
    for j = 1:sbCalc(i)-1
        for k = j+1:sbCalc(i)
            sbDist(j,k) = min(sbMatrix(k,:))-max(sbMatrix(j,:));
            sbDist(k,j) = sbDist(j,k);
        end
    end
    
    sbAllowed=sbDist>=22;
    pairs = zeros(1,sbCalc(i));
    subbands = 1:sbCalc(i);
    level = 1;
    maxConst = 0;
    [pairs, maxConst] = pairsComp_v2(pairs, maxConst, level, subbands, sbAllowed, pairs, pairs);
    if maxConst>0
        for i = 1:length(pairs)
            if sbAllowed(i,pairs(i)) == 0
                pairs(i) = 0;
            end
        end
    end
    
    availableSubbands = sbCalc(selected);
% ########################################################################
% Save variables to file
% ######################################################################## 
    if fhAlgorithm == 2
        cellIds = 0:size(subbandHS,1)*size(indexHS,1)-1;
        Period = size(subbandHS, 2)*size(indexHS,2);
        save( 'matfiles\calcHS', 'availableSubbands', 'noOfSubbands', 'widthOfSubbands', 'sbMatrix', 'pairs', 'subbandHS', 'indexHS');
        
    elseif fhAlgorithm == 3
        I = find(allNumbers <= sum(seqLenghts), 1, 'last');
        downlinkHS = galoisCalc(allNumbers(I));
        Period = size(downlinkHS,2);
        cellIds = 0:size(downlinkHS,1)-1;
        save( 'matfiles\calcHS', 'downlinkHS', 'subbandHS', 'indexHS');
    end